@@ -9,9 +9,11 @@ from wrapt.importer import when_imported
 from .log import init as log_init, logger
 from .sdk import init as sdk_init
 
-log_level_name = os.environ.get("AUTDYNATRACE_LOG_LEVEL", "WARNING")
+log_level_name = os.environ.get("AUTODYNATRACE_LOG_LEVEL", "WARNING")
 log_init(logging.getLevelName(log_level_name))
-sdk_init()
+
+forkable = os.environ.get("AUTODYNATRACE_FORKABLE", "False").strip().lower() in ("true", "1")
+sdk_init(forkable=forkable)
 
 from .wrappers.custom import dynatrace_custom_tracer as trace
 
@@ -27,14 +29,10 @@ INSTRUMENT_LIBS = {
     "sqlalchemy": True,
     "django": True,
     "redis": True,
+    "pika": True,
 }
 
 
-def set_forkable():
-    sdk.shutdown()
-    sdk.init(forkable=True)
-
-
 def instrument_all(**instrument_libs):
     libs = INSTRUMENT_LIBS.copy()
     libs.update(instrument_libs)
